@@ -1,5 +1,5 @@
 /*
-//@line 42 "/usr/obj/ports/mozilla-firefox-1.5.0.3/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 42 "/usr/obj/ports/mozilla-firefox-1.5.0.4/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
 */
 
 /* This file implements the nsIHelperAppLauncherDialog interface.
@@ -99,9 +99,9 @@ nsUnknownContentTypeDialog.prototype = {
           if (aFolderType != "Downloads")
             throw "ASSERTION FAILED: folder type should be 'Desktop' or 'Downloads'";
         
-//@line 147 "/usr/obj/ports/mozilla-firefox-1.5.0.3/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 147 "/usr/obj/ports/mozilla-firefox-1.5.0.4/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
           return "Home";
-//@line 150 "/usr/obj/ports/mozilla-firefox-1.5.0.3/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 150 "/usr/obj/ports/mozilla-firefox-1.5.0.4/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
         }
         
         function getDownloadsFolder(aFolder)
@@ -356,7 +356,7 @@ nsUnknownContentTypeDialog.prototype = {
       // want users to be able to autodownload .exe files. 
       var rememberChoice = this.dialogElement("rememberChoice");
 
-//@line 424 "/usr/obj/ports/mozilla-firefox-1.5.0.3/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 424 "/usr/obj/ports/mozilla-firefox-1.5.0.4/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       var mimeType = this.mLauncher.MIMEInfo.MIMEType;
       if (mimeType == "application/octet-stream" || 
           mimeType == "application/x-msdownload" ||
@@ -386,9 +386,12 @@ nsUnknownContentTypeDialog.prototype = {
     
     _timer: null,
     notify: function (aTimer) {
-      if (!this._blurred)
-        this.mDialog.document.documentElement.getButton('accept').disabled = false;
+      try { // The user may have already canceled the dialog.
+        if (!this._blurred)
+          this.mDialog.document.documentElement.getButton('accept').disabled = false;
+      } catch (ex) {}
       this._delayExpired = true;
+      this._timer = null; // the timer won't release us, so we have to release it
     },
     
     postShowCallback: function () {
@@ -488,12 +491,12 @@ nsUnknownContentTypeDialog.prototype = {
         var result;
 
         // The checking is different on Windows...
-//@line 569 "/usr/obj/ports/mozilla-firefox-1.5.0.3/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 572 "/usr/obj/ports/mozilla-firefox-1.5.0.4/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
             // On other platforms, default is Ok if there is a default app.
             // Note that nsIMIMEInfo providers need to ensure that this holds true
             // on each platform.
         return this.mLauncher.MIMEInfo.hasDefaultHandler;
-//@line 574 "/usr/obj/ports/mozilla-firefox-1.5.0.3/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 577 "/usr/obj/ports/mozilla-firefox-1.5.0.4/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
     },
     
     // Set "default" application description field.
@@ -514,9 +517,9 @@ nsUnknownContentTypeDialog.prototype = {
 
     // getPath:
     getPath: function (aFile) {
-//@line 597 "/usr/obj/ports/mozilla-firefox-1.5.0.3/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 600 "/usr/obj/ports/mozilla-firefox-1.5.0.4/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       return aFile.path;
-//@line 599 "/usr/obj/ports/mozilla-firefox-1.5.0.3/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 602 "/usr/obj/ports/mozilla-firefox-1.5.0.4/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
     },
 
     // initAppAndSaveToDiskValues:
@@ -584,9 +587,9 @@ nsUnknownContentTypeDialog.prototype = {
       }
       
       // otherHandler is always disabled on Mac
-//@line 670 "/usr/obj/ports/mozilla-firefox-1.5.0.3/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 673 "/usr/obj/ports/mozilla-firefox-1.5.0.4/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       otherHandler.nextSibling.hidden = otherHandler.nextSibling.nextSibling.hidden = false;
-//@line 672 "/usr/obj/ports/mozilla-firefox-1.5.0.3/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 675 "/usr/obj/ports/mozilla-firefox-1.5.0.4/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
       this.updateOKButton();
     },
 
@@ -739,7 +742,7 @@ nsUnknownContentTypeDialog.prototype = {
           // for the file to be saved to to pass to |saveToDisk| - otherwise
           // we must ask the user to pick a save name.
 
-//@line 838 "/usr/obj/ports/mozilla-firefox-1.5.0.3/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
+//@line 841 "/usr/obj/ports/mozilla-firefox-1.5.0.4/mozilla/toolkit/mozapps/downloads/src/nsHelperAppDlg.js.in"
           this.mLauncher.saveToDisk(null, false);
         }
         else
